@@ -14,7 +14,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-slack-chatbot", "1.0.98", __name__[0:-6], "cdk-slack-chatbot@1.0.98.jsii.tgz"
+    "cdk-slack-chatbot",
+    "1.0.111",
+    __name__[0:-6],
+    "cdk-slack-chatbot@1.0.111.jsii.tgz",
 )
 
 __all__ = [
